import setuptools


setuptools.setup(
    name='san_make',
    version='1.0.1',
    author='',
    description='',
    long_description_content_type='text/markdown',
    url='https://github.com/',
    packages=setuptools.find_packages(),
    classfile=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],

)